@@ -41,6 +41,7 @@
 void
 fill_tttext_with_input_description (GtkListStore* ttListStore)
 {
+  g_debug ("Couocu");
   gtk_tree_model_foreach (GTK_TREE_MODEL (ttListStore),
 			  set_description, NULL);
 }
@@ -70,7 +71,7 @@ set_comment (GtkTreeModel* ttListStore, GtkTreePath* path,
   gtk_tree_model_get (ttListStore, iter, 0, &command,
 		      3, &postComment, -1);
   
-  if ((strcmp (ttPrevInput, command) == 0))
+  if ((strncmp (ttPrevInput, command, strlen (command)) == 0))
     {
       strcpy (ttText, postComment);
       g_free (command);
@@ -92,18 +93,20 @@ set_description (GtkTreeModel *ttListStore, GtkTreePath *path,
   gchar *command, *description, *example;
   UNUSED (path);
   UNUSED (user_data);
-  
   gtk_tree_model_get (ttListStore, iter, 0, &command, 1, &description,
 		      2, &example, -1);
 
-  if ((strcmp (ttInput, command) == 0))
+  if ((strncmp (ttInput, command, strlen (command)) == 0))
     {
       strcpy (ttText, g_markup_printf_escaped
-	("<span weight=\"bold\" color=\"red\">%s</span> : %s",
-	 command, description));
-      strcpy (ttTextExample, g_markup_printf_escaped ("%s", example));
+	      (_("<span color=\"red\">Command: <span weight=\"bold\">%s</span></span> : %s"), command, description));
+      
+      if (strlen (example))
+	strcpy (ttTextExample, g_markup_printf_escaped ("%s", example));
+      
       g_free (command);
       g_free (description);
+      g_free (example);
       return TRUE;
     }
   strcpy (ttText, "");
@@ -121,7 +124,21 @@ void
 update_input (gchar* keyval)
 {
   size_t length = strlen (ttInput);
-  
+  /* TODO:
+   * Bon, déjà, cette fonction ne devrait pas s'appeler update_input.
+   * Ensuite, rien ne sert de relancer un scan complet de la liste
+   * des commandes à chaque nouvel appui sur la touche du clavier !
+   * Mettre à jour une chaine de caractère (ttInput) n'est pas la
+   * bonne méthode. Il faut que cette fonction réfléchisse :
+   *  1. Est-on en train d'écrire une commande ?
+   *  2.  "   "  "   "        "   une option ?
+   *  3.  "   "  "   "        "   un argument ?
+   *  4. Est-on en train de faire une faute (ou en tout cas d'écrire
+   * une commande non prise en charge) ?
+   *  5. Est-on en train d'effacer ce qu'on a écrit ?
+   *  6. A-t-on fini d'écrire ?
+   * etc.
+   */
   if (strcmp (keyval, "BackSpace") == 0)
     {
       if (length >= 1)
