@@ -91,7 +91,7 @@ text (GMarkupParseContext *context,
   GValue content = G_VALUE_INIT;
   g_value_init (&content, G_TYPE_STRING);
 
-  if (&iter != NULL && text_len != 0)
+  if (text_len != 0)
     {
       g_value_set_static_string	(&content,
 				 g_strcompress (g_strchug (text)));
